@@ -9,7 +9,7 @@ from .core.torch_utils import TorchLoaderBase as torch_loader
 from .core.numpy_utils import NumpyLoaderBase as np_loader
 from .core.numpy_utils import SemsegLoader as seg_loader
 from .core.tensorflow_utils import TFLoaderBase as tf_loader
-from .core.lyftbag_utils import CamLoader
+from .core.lyftbag_utils import CamLoader, LyftbagParser
 from .core.query_utils import QueryDataset
 
-__version__ = '0.0.31'
\ No newline at end of file
+__version__ = '0.0.32'
\ No newline at end of file
