@@ -29,7 +29,9 @@ import numpy as np
 
 from google.protobuf.descriptor_pool import DescriptorPool
 from google.protobuf.message_factory import MessageFactory
+from google.protobuf.json_format import MessageToDict
 from ..protos.mas import lyftbag_pb2
+from .lyftbag_topics import SUPPORTED_TOPICS
 
 log = logging.getLogger(__name__)
 '''
@@ -450,7 +452,7 @@ class LyftbagReaderv00(LyftbagReader):
 
 
 class CamLoader(object):
-    """ Mas lyftbad reader class  """
+    """ Mas lyftbad camera topic reader class  """
 
     def __init__(self, lyftbag, **job):
         self.jc = {
@@ -473,5 +475,46 @@ class CamLoader(object):
                 cam_payload = lyftbag_pb2.CompressedImage()
                 cam_payload.ParseFromString(payload)
                 im = cv2.imdecode(np.fromstring(cam_payload.data, dtype=np.uint8), -1)
-                cam_data = {"meta": cam_payload.metadata, "image": im}
-                yield cam_data
\ No newline at end of file
+                cam_data = {"meta": cam_payload.metadata, 
+                            "format": cam_payload.compression_format,
+                            "image": im}
+                yield cam_data
+
+
+class LyftbagParser(object):
+    """ Mas lyftbad general topic reader class  """
+
+    def __init__(self, lyftbag, **job):
+        self.jc = {
+            'topics' : None,
+            'start_timestamp_ns' : 0,
+            'end_timestamp_ns' : sys.maxsize
+        }
+        self.jc.update(job)
+        self.lyftbag = lyftbag
+        if self.jc['topics']:
+            self.allowed_topics = self.jc['topics']
+        else:
+            self.allowed_topics = list(SUPPORTED_TOPICS.keys())
+        self.frames = self._frame_provider()
+    
+    def _frame_provider(self):
+        """ provide camer frames from lyftbag """
+        with Lyftbag(self.lyftbag, None, 
+                     self.jc['start_timestamp_ns'],
+                     self.jc['end_timestamp_ns'],
+                     'r') as bag:
+            for meta, payload in bag.read_messages():
+                meta_as_dict = MessageToDict(meta,
+                                             including_default_value_fields=True,
+                                             preserving_proto_field_name=True)
+                proto_as_dict = None
+                if meta.topic in self.allowed_topics:
+                    proto_class = SUPPORTED_TOPICS[meta.topic]
+                    proto = proto_class()
+                    proto.ParseFromString(payload)
+                    proto_as_dict = MessageToDict(proto,
+                                                  including_default_value_fields=True,
+                                                  preserving_proto_field_name=True)
+                    
+                yield {'metadata': meta_as_dict, 'payload': proto_as_dict}
\ No newline at end of file
